import 'package:flutter/material.dart';
import 'package:hx_components_flutter/src/shared/app_colors.dart';
import 'package:hx_components_flutter/src/widgets/hx_text.dart';

class HxCardButton extends StatelessWidget {
  final Color? backgroundColor;
  final Color? textColor;
  final String title;
  final IconData icon;
  final VoidCallback homeNavigation;

  const HxCardButton({
    this.backgroundColor = Colors.white,
    this.textColor = Colors.black,
    required this.title,
    required this.icon,
    required this.homeNavigation,
  });

  @override
  Widget build(BuildContext context) {
    return Expanded(
      child: SizedBox(
        height: MediaQuery.of(context).size.height * 0.18,
        child: Card(
          color: backgroundColor,
          shadowColor: kcGrey,
          shape: RoundedRectangleBorder(
            borderRadius: BorderRadius.circular(10),
            side: const BorderSide(color: kcLightGrey),
          ),
          elevation: 2,
          child: InkWell(
            onTap: homeNavigation,
            splashColor: kcPrimaryColor,
            borderRadius: BorderRadius.circular(10),
            child: Container(
              decoration: BoxDecoration(
                borderRadius: BorderRadius.circular(10),
              ),
              padding: const EdgeInsets.fromLTRB(20, 20, 20, 11),
              child: Column(
                crossAxisAlignment: CrossAxisAlignment.start,
                mainAxisAlignment: MainAxisAlignment.spaceBetween,
                children: <Widget>[
                  Icon(
                    icon,
                    size: 33,
                    color: kcPrimaryColor,
                  ),
                  Expanded(
                    child: Container(
                      alignment: Alignment.bottomLeft,
                      child: HxText.heading3(
                        title,
                        fontWeight: FontWeight.normal,
                      ),
                    ),
                  ),
                ],
              ),
            ),
          ),
        ),
      ),
    );
  }
}
