import 'package:dropdown_search/dropdown_search.dart';
import 'package:flutter/material.dart';
import 'package:hx_components_flutter/src/shared/app_colors.dart';

class HxDropdownSearch<T> extends StatefulWidget {
  final String label;
  final String? hint;
  final List<T> items;
  final T? initialSelectedItem;
  T? selectedItem;
  final Function(T?) onChanged;
  final Future<List<T>> Function(String)? asyncItems;
  final Widget Function(BuildContext, T, bool)? itemBuilder;
  final bool enabled;
  final Widget Function(BuildContext, T?)? dropdownBuilder;

  HxDropdownSearch({
    super.key,
    required this.items,
    required this.onChanged,
    required this.label,
    this.hint,
    this.initialSelectedItem,
    this.itemBuilder,
    this.enabled = true,
    this.dropdownBuilder,
  }) : asyncItems = null;

  HxDropdownSearch.async({
    super.key,
    required this.onChanged,
    required this.label,
    this.hint,
    required this.asyncItems,
    this.initialSelectedItem,
    this.itemBuilder,
    this.enabled = true,
    this.dropdownBuilder,
  }) : items = [];

  @override
  State<HxDropdownSearch<T>> createState() => _HxDropdownSearchState<T>();
}

class _HxDropdownSearchState<T> extends State<HxDropdownSearch<T>> {
  @override
  Widget build(BuildContext context) {
    return DropdownSearch<T>(
      enabled: widget.enabled,
      asyncItems: widget.asyncItems,
      selectedItem: widget.initialSelectedItem,
      dropdownBuilder: widget.selectedItem != null ? widget.dropdownBuilder : null,
      popupProps: PopupProps.menu(
        itemBuilder: widget.itemBuilder,
        fit: FlexFit.loose,
        showSearchBox: true,
        searchFieldProps: const TextFieldProps(
          style: TextStyle(fontSize: 16),
          decoration: InputDecoration(
            suffixIcon: Icon(Icons.search),
            labelStyle: TextStyle(color: kcPrimaryColor),
            border: OutlineInputBorder(
              borderSide: BorderSide(color: kcPrimaryColor),
            ),
          ),
        ),
      ),
      items: widget.items,
      dropdownDecoratorProps: DropDownDecoratorProps(
        baseStyle: const TextStyle(fontSize: 16),
        dropdownSearchDecoration: InputDecoration(
          labelText: widget.label,
          hintText: widget.hint,
          filled: true,
          fillColor: kcLightGrey,
          isDense: true,
        ),
      ),
      onChanged: (value) {
        widget.onChanged(value);
        setState(() {
          widget.selectedItem = value;
        });
      },
    );
  }
}
